==> PPDF_1_4.zip: PubMedPDF/index.php <==
<?php
	include "header.php";
	include "style.php";

	# registered item number
	$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_id');
	$res = $xoopsDB->query($sql);
	echo "<b>".$xoopsDB->getRowsNum($res)."</b> papers registered<br><br><br>";

  ### Shortcut ###
	if($xoopsUser){
		$user = $xoopsUser->uname();
		
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_shortcut')." WHERE Usr='".$user."' ORDER BY Target";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res) > 0){
			echo "<div class='pt'>Shortcut</div>";
			echo "<table style='width:100%'><tr>";
			$i=0;
			while($row = $xoopsDB->fetchArray($res)){
				$pass = XOOPS_URL."/modules/PubMedPDF/".$row['Target'];
				
				$url ="[<a href='".$_SERVER[PHP_SELF]."?scutdel=".$row['id']."'><img src='images/delete.png'></a>] ";
				$url.= "<a href='".$pass."'>".$row['Name']."</a>";

				if(!($i % 3)) echo "</tr><tr>";
				echo "<td style='width:33%'>".$url."</td>";
				$i++;
			}
			echo "</tr></table><br>";
		}
	}

	### Shortcut delete ###
	if(isset($_GET['scutdel'])){
		$id = intval($_GET['scutdel']);
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_shortcut')." WHERE id='".$id."'";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res) > 0){
			$sql = "DELETE FROM ".$xoopsDB->prefix('pmid_shortcut')." WHERE id='".$id."'";
			$res = $xoopsDB->queryF($sql);
		}
		$url = XOOPS_URL."/modules/PubMedPDF/index.php";
		header("Location: $url");
	}
	

	### Author ###
	echo "<div class='pt'>Author</div>";
	for($i='A',$j=0; $j<26; $i++,$j++){
		$sql = "SELECT id FROM ".$xoopsDB->prefix('pmid_author')." WHERE Author LIKE '".$i."%'ORDER BY Author";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res)) echo "<a href='author.php?initial=".$i."'>".$i."</a> &nbsp;";
	}
	echo "<br><br>";


	### Year ###
	$year = array();
	echo "<div class='pt'>Year</div>";
	$sql = "SELECT Year FROM ".$xoopsDB->prefix('pmid_id')." ORDER BY Year";
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)){
		$year[$row['Year']] ++;
	}
	echo "<table><tr>";
	$i=0;
	foreach($year as $key => $value){
		if(!($i % 8)) echo "</tr><tr>";
		echo "<td><a href='year.php?year=".$key."'>".$key."</a> (".$value.") &nbsp;</td>";
		$i++;
	}
	echo "</tr></table><br>";


	### Journal ###
	echo "<div class='pt'>Journal</div>";

	#journal initial
	$link = array();
	$sql = "SELECT Journal FROM ".$xoopsDB->prefix('pmid_journal')." ORDER BY Journal";
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)){
		if($row['Journal'] == '(unknown)') continue;
		$i = substr($row['Journal'],0,1);
		if(!in_array($i,$link)) $link[] = $i;
	}
	for($i=0; $i<count($link); $i++){
		echo "<a href='#".$link[$i]."'>".$link[$i]."</a>&nbsp;&nbsp;";
	}
	echo "<br><br>";

	$sql = "SELECT id, Journal, Book FROM ".$xoopsDB->prefix('pmid_journal')." ORDER BY Journal";
	$res = $xoopsDB->query($sql);
	$j = array();
	$index = array();
	while($row = $xoopsDB->fetchArray($res)){
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_id')." WHERE Journal='".$row['id']."'";
		$res2 = $xoopsDB->query($sql);
		(strlen($row['Journal']) > 18) ? $J=substr($row['Journal'],0,18)."..." : $J=$row['Journal'];
		if($xoopsDB->getRowsNum($res2)){
			$index[] = substr($J,0,1);
			if($row['Book']) $J = "<i>".$J."</i>";
			$j[] = "<a href='journal.php?journal=".$row['id']."'>".$J."</a> (".$xoopsDB->getRowsNum($res2).")";
		}
	}

	# Journal method
	$pre_index = "";
	echo "<table><tr>";
	for($i=0,$td=0; $i<count($j); $i++,$td++){

		if($index[$i] != $pre_index){
			if($td == 0){
				if($index[$i] != "("){
					echo "</tr><tr><td colspan='3' class='even'>";
					echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				}
			}elseif($td == 1){
				echo "<td> </td><td> </td>";
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}elseif(($td == 2)){
				echo "<td> </td>";
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}elseif($td == 3){
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}

		}else{
			if($td == 3){
				echo "</tr><tr>";
				$td = 0;
			}
		}

		echo "<td style='width:33%'>".$j[$i]."</td>";
		$pre_index = $index[$i];
	}
	echo "</tr></table>";

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_5.zip: PubMedPDF/index.php <==
<?php
	include 'nheader.php';
	include XOOPS_ROOT_PATH.'/header.php';
	include 'style.php';

	$navi= "<a href=\"http://www.web-learner.com/\" target=\"_blank\">[Help]</a> ";
	$navi.= "<a href=\"http://www.ncbi.nlm.nih.gov/entrez/query.fcgi\" target=\"_blank\">[PubMed]</a> ";

	### Shortcut delete ###
	if(isset($_GET['scutdel'])){
		$id = intval($_GET['scutdel']);
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_shortcut')." WHERE id='".$id."'";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res) > 0){
			$sql = "DELETE FROM ".$xoopsDB->prefix('pmid_shortcut')." WHERE id='".$id."'";
			$res = $xoopsDB->queryF($sql);
		}
		redirect_header(MOD_URL, 1, _MD_SCUTDEL);
	}

	$res = $xoopsDB->query("SELECT * FROM ".$xoopsDB->prefix('pmid_id'));
	echo "<table style='width:100%; margin-bottom:20px'><tr>";
	echo "<td><b>".$xoopsDB->getRowsNum($res)."</b> papers registered</td>";
	echo "<td style='text-align:right'>".$navi."</td>";
	echo "</tr></table>";

  ### Shortcut ###
	if($user != 'guest'){
		
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_shortcut');
		$sql.= " WHERE Usr='".$user."' ORDER BY Target";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res) > 0){
			echo "<div class='pt'>"._MD_SCUT."</div>";
			echo "<table style='width:100%'><tr>";
			$i=0;
			while($row = $xoopsDB->fetchArray($res)){
				$pass = XOOPS_URL."/modules/PubMedPDF/".$row['Target'];
				
				$url ="[<a href='index.php?scutdel=".$row['id']."'><img src='images/delete.png'></a>] ";
				$url.= "<a href='".$pass."'>".$row['Name']."</a>";

				if(!($i % 3)) echo "</tr><tr>";
				echo "<td style='width:33%'>".$url."</td>";
				$i++;
			}
			echo "</tr></table><br>";
		}
	}	

	### Author ###
	echo "<div class='pt'>"._MD_AUTHOR."</div>";
	for($i='A',$j=0; $j<26; $i++,$j++){
		$sql = "SELECT id FROM ".$xoopsDB->prefix('pmid_author')." WHERE Author LIKE '".$i."%'ORDER BY Author";
		$res = $xoopsDB->query($sql);
		if($xoopsDB->getRowsNum($res)) echo "<a href='author.php?initial=".$i."'>".$i."</a> &nbsp;";
	}
	echo "<br><br>";


	### Year ###
	$year = array();
	echo "<div class='pt'>"._MD_YEAR."</div>";
	$sql = "SELECT Year FROM ".$xoopsDB->prefix('pmid_id')." ORDER BY Year";
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)){
		if(!isset($year[$row['Year']])) $year[$row['Year']] = 0;
		$year[$row['Year']] ++;
	}
	echo "<table><tr>";
	$i=0;
	foreach($year as $key => $value){
		if(!($i % 8)) echo "</tr><tr>";
		echo "<td><a href='year.php?year=".$key."'>".$key."</a> (".$value.") &nbsp;</td>";
		$i++;
	}
	echo "</tr></table><br>";


	### Journal ###
	echo "<div class='pt'>"._MD_JB."</div>";

	#journal initial
	$link = array();
	$sql = "SELECT Journal FROM ".$xoopsDB->prefix('pmid_journal')." ORDER BY Journal";
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)){
		if($row['Journal'] == '(unknown)') continue;
		$i = strtoupper(substr($row['Journal'],0,1));
		if(!in_array($i,$link)) $link[] = $i;
	}
	for($i=0; $i<count($link); $i++){
		echo "<a href='#".$link[$i]."'>".$link[$i]."</a>&nbsp;&nbsp;";
	}
	echo "<br><br>";

	$sql = "SELECT id, Journal, Book FROM ".$xoopsDB->prefix('pmid_journal')." ORDER BY Journal";
	$res = $xoopsDB->query($sql);
	$j = array();
	$index = array();
	while($row = $xoopsDB->fetchArray($res)){
		$sql = "SELECT * FROM ".$xoopsDB->prefix('pmid_id')." WHERE Journal='".$row['id']."'";
		$res2 = $xoopsDB->query($sql);
		(strlen($row['Journal']) > 18) ? $J=substr($row['Journal'],0,18)."..." : $J=$row['Journal'];
		if($xoopsDB->getRowsNum($res2)){
			$index[] = strtoupper(substr($J,0,1));
			if($row['Book']) $J = "<i>".$J."</i>";
			$j[] = "<a href='journal.php?journal=".$row['id']."'>".$J."</a> (".$xoopsDB->getRowsNum($res2).")";
		}
	}

	# Journal method
	$pre_index = "";
	echo "<table><tr>";
	for($i=0,$td=0; $i<count($j); $i++,$td++){

		if($index[$i] != $pre_index){
			if($td == 0){
				if($index[$i] != "("){
					echo "</tr><tr><td colspan='3' class='even'>";
					echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				}
			}elseif($td == 1){
				echo "<td> </td><td> </td>";
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}elseif(($td == 2)){
				echo "<td> </td>";
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}elseif($td == 3){
				echo "</tr><tr><td colspan='3' class='even'>";
				echo "<a name='".$index[$i]."'></a>".$index[$i]."</td></tr><tr>";
				$td = 0;
			}

		}else{
			if($td == 3){
				echo "</tr><tr>";
				$td = 0;
			}
		}

		echo "<td style='width:33%'>".$j[$i]."</td>";
		$pre_index = $index[$i];
	}
	echo "</tr></table>";

	include (XOOPS_ROOT_PATH."/footer.php");
?>
